translate.convert.prop2mozfunny

Package translate :: Package convert :: Module prop2mozfunny |
[hide private]
[frames] | no frames]

# Module prop2mozfunny

source code

converts properties files back to funny mozilla files

Functions | [hide private]
prop2inc(pf) convert a properties file back to a .inc file with #defines in it | source code
prop2it(pf) convert a properties file back to a pseudo-properties .it file | source code
prop2funny(src, itencoding="cp1252") | source code
po2inc(inputfile, outputfile, templatefile, encoding=None, includefuzzy=False) wraps po2prop but converts outputfile to properties first | source code
po2it(inputfile, outputfile, templatefile, encoding="cp1252", includefuzzy=False) wraps po2prop but converts outputfile to properties first | source code
po2ini(inputfile, outputfile, templatefile, encoding="UTF-8", includefuzzy=False) wraps po2prop but converts outputfile to properties first using UTF-8 encoding | source code
main(argv=None) | source code

Imports: properties, po2prop, mozfunny2prop, StringIO